pub struct SqliteStore { /* private fields */ }Implementations
Sourceimpl SqliteStore
impl SqliteStore
Handle for sibling crates to run their own queries and migrations against this store’s database file through the same pool and semaphore.
Sourceimpl SqliteStore
impl SqliteStore
Sourcepub async fn new(database_url: &str) -> Result<Self, StoreError>
pub async fn new(database_url: &str) -> Result<Self, StoreError>
Open a store with the default low-memory SqliteStoreConfig.
Sourcepub async fn with_config(
database_url: &str,
config: SqliteStoreConfig,
) -> Result<Self, StoreError>
pub async fn with_config( database_url: &str, config: SqliteStoreConfig, ) -> Result<Self, StoreError>
Open a store with a custom SqliteStoreConfig (the default favours low memory /
high session density; override to trade memory for concurrency or cache).
pub async fn new_for_device( database_url: &str, device_id: i32, ) -> Result<Self, StoreError>
Sourcepub async fn with_config_for_device(
database_url: &str,
device_id: i32,
config: SqliteStoreConfig,
) -> Result<Self, StoreError>
pub async fn with_config_for_device( database_url: &str, device_id: i32, config: SqliteStoreConfig, ) -> Result<Self, StoreError>
Open a store for a specific device with a custom SqliteStoreConfig.
pub fn device_id(&self) -> i32
pub async fn save_device_data_for_device( &self, device_id: i32, device_data: &CoreDevice, ) -> Result<()>
pub async fn create_new_device(&self) -> Result<i32>
pub async fn device_exists(&self, device_id: i32) -> Result<bool>
pub async fn load_device_data_for_device( &self, device_id: i32, ) -> Result<Option<CoreDevice>>
pub async fn put_identity_for_device( &self, address: &str, key: [u8; 32], device_id: i32, ) -> Result<()>
pub async fn delete_identity_for_device( &self, address: &str, device_id: i32, ) -> Result<()>
pub async fn load_identity_for_device( &self, address: &str, device_id: i32, ) -> Result<Option<Vec<u8>>>
pub async fn get_session_for_device( &self, address: &str, device_id: i32, ) -> Result<Option<Vec<u8>>>
pub async fn put_session_for_device( &self, address: &str, session: &[u8], device_id: i32, ) -> Result<()>
pub async fn delete_session_for_device( &self, address: &str, device_id: i32, ) -> Result<()>
pub async fn put_sender_key_for_device( &self, address: &str, record: &[u8], device_id: i32, ) -> Result<()>
pub async fn get_sender_key_for_device( &self, address: &str, device_id: i32, ) -> Result<Option<Vec<u8>>>
pub async fn delete_sender_key_for_device( &self, address: &str, device_id: i32, ) -> Result<()>
pub async fn get_app_state_sync_key_for_device( &self, key_id: &[u8], device_id: i32, ) -> Result<Option<AppStateSyncKey>>
pub async fn set_app_state_sync_key_for_device( &self, key_id: &[u8], key: AppStateSyncKey, device_id: i32, ) -> Result<()>
pub async fn get_latest_app_state_sync_key_id_for_device( &self, device_id: i32, ) -> Result<Option<Vec<u8>>>
pub async fn get_app_state_version_for_device( &self, name: &str, device_id: i32, ) -> Result<HashState>
pub async fn set_app_state_version_for_device( &self, name: &str, state: HashState, device_id: i32, ) -> Result<()>
pub async fn put_app_state_mutation_macs_for_device( &self, name: &str, version: u64, mutations: &[AppStateMutationMAC], device_id: i32, ) -> Result<()>
pub async fn delete_app_state_mutation_macs_for_device( &self, name: &str, index_macs: &[Vec<u8>], device_id: i32, ) -> Result<()>
pub async fn get_app_state_mutation_mac_for_device( &self, name: &str, index_mac: &[u8], device_id: i32, ) -> Result<Option<Vec<u8>>>
Sourcepub async fn get_app_state_mutation_macs_batch_for_device(
&self,
name: &str,
index_macs: &[[u8; 32]],
device_id: i32,
) -> Result<HashMap<[u8; 32], Vec<u8>>>
pub async fn get_app_state_mutation_macs_batch_for_device( &self, name: &str, index_macs: &[[u8; 32]], device_id: i32, ) -> Result<HashMap<[u8; 32], Vec<u8>>>
Batched read of previous-MAC values for many index_macs in one query
(single spawn_blocking + index_mac IN (...)), replacing the per-mutation
N+1 in appstate sync.